# Authors

## Python bindings

* Sophia Andaloro <sja5@rice.edu> @sophiaandaloro
* Christopher Tunnell <tunnell@rice.edu> @tunnell
* Nicholas Carrara <ncarrara@albany.edu> @infophysics

## NEST

For the NEST library that this wraps, this was made by the NEST Collaboration (http://nest.physics.ucdavis.edu)

## Other

For indirect help:

* Henry Shreiner <henry.fredrick.schreiner@cern.ch> @henryiii
